==> screem_0.4.1.orig.tar.gz: screem-0.4.1/include/entities.h <==

/* html entities */
static gchar* ISO_8859_1[] = {
	"nbsp", "iexcl", "cent", "pound", "curren", "yen", "brvbar",
	"sect", "uml", "copy", "ordf", "laquo", "not", "shy", "reg",
	"macr", "deg", "plusmn", "sup2", "sup3", "acute", "micro",
	"para", "middot", "cedil", "sup1", "ordm", "raquo", "frac14",
	"frac12", "frac34", "iquest", "Agrave", "Aacute", "Acirc",
	"Atilde", "Auml", "Aring", "AElig", "Ccedil", "Egrave",
	"Eacute", "Ecirc", "Euml", "Igrave", "Iacute", "Icirc",
	"Iuml", "ETH", "Ntilde", "Ograve", "Oacute", "Ocirc", "Otilde",
	"Ouml", "times", "Oslash", "Ugrave", "Uacute", "Ucirc", "Uuml",
	"Yacute", "THORN", "szlig", "agrave", "aacute", "acirc",
	"atilde", "auml", "aring", "aelig", "ccedil", "egrave", "eacute",
	"ecirc", "euml", "igrave", "iacute", "icirc", "iuml", "eth",
	"ntilde", "ograve", "oacute", "ocirc", "otilde", "ouml", "divide",
	"oslash", "ugrave", "uacute", "ucirc", "uuml", "yacute", "thorn",
	"yuml", NULL
};
static gchar* MATH_GREEK_SYMBOLIC[] = {
	"fnof", "Alpha", "Beta", "Gamma", "Delta", "Epsilon", "Zeta", "Eta",
	"Theta", "Iota", "Kappa", "Lambda", "Mu", "Nu", "Xi", "Omicron",
	"Pi", "Rho", "Sigma", "Tau", "Uplsilon", "Phi", "Chi", "Psi", "Omega",
	"alpha", "beta", "gamma", "delta", "epsilon", "zeta", "eta", "theta",
	"iota", "kappa", "lambda", "mu", "nu", "xi", "omicron", "pi", "rho",
	"sigmaf","sigma", "tau", "upsilon", "phi", "chi", "psi", "omega",
	"thetasym", "upsih", "piv", "bull", "hellip", "prime", "Prime",
	"oline", "frasl", "weierp", "image", "real", "trade", "alefsym",
	"larr", "uarr", "rarr", "darr", "harr", "crarr", "lArr", "uArr",
	"rArr", "dArr", "hArr", "forall", "part", "exist", "empty", "nabla",
	"isin" "notin", "ni", "prod", "sum", "minus", "lowast", "radic", 
	"prop", "infin", "ang", "and", "or", "cap", "cup", "int", "there4",
	"sim", "cong", "asymp", "ne", "equiv", "le", "ge", "sub", "sup",
	"nsub", "sube", "supe", "oplus", "otimes", "perp", "sdot", "lceil",
	"rceil", "lfloor", "rfloor", "lang", "rang", "loz", "spades", "clubs",
	"hearts", "diams", NULL
};

static gchar* MARKUP_INTL[] = {
	"quot", "amp", "lt", "gt", "OElig", "oelig", "Scaron", "scaron",
	"Yuml", "circ", "tilde", "ensp", "emsp", "thinsp", "zwnj", "zwj", 
	"lrm", "rlm", "ndash", "mdash", "lsquo", "rsquo", "sbquo", "ldquo",
	"rdquo", "bdquo", "dagger", "Dagger", "permil", "lsaquo", "rsaquo",
	"euro",	NULL
};

==> screem_0.12.1.orig.tar.gz: screem-0.12.1/include/entities.h <==

/* html entities */
static gchar* ISO_8859_1[] = {
	"nbsp", "iexcl", "cent", "pound", "curren", "yen", "brvbar",
	"sect", "uml", "copy", "ordf", "laquo", "not", "shy", "reg",
	"macr", "deg", "plusmn", "sup2", "sup3", "acute", "micro",
	"para", "middot", "cedil", "sup1", "ordm", "raquo", "frac14",
	"frac12", "frac34", "iquest", "Agrave", "Aacute", "Acirc",
	"Atilde", "Auml", "Aring", "AElig", "Ccedil", "Egrave",
	"Eacute", "Ecirc", "Euml", "Igrave", "Iacute", "Icirc",
	"Iuml", "ETH", "Ntilde", "Ograve", "Oacute", "Ocirc", "Otilde",
	"Ouml", "times", "Oslash", "Ugrave", "Uacute", "Ucirc", "Uuml",
	"Yacute", "THORN", "szlig", "agrave", "aacute", "acirc",
	"atilde", "auml", "aring", "aelig", "ccedil", "egrave", "eacute",
	"ecirc", "euml", "igrave", "iacute", "icirc", "iuml", "eth",
	"ntilde", "ograve", "oacute", "ocirc", "otilde", "ouml", "divide",
	"oslash", "ugrave", "uacute", "ucirc", "uuml", "yacute", "thorn",
	"yuml", NULL
};
static gchar* MATH_GREEK_SYMBOLIC[] = {
	"fnof", "Alpha", "Beta", "Gamma", "Delta", "Epsilon", "Zeta", "Eta",
	"Theta", "Iota", "Kappa", "Lambda", "Mu", "Nu", "Xi", "Omicron",
	"Pi", "Rho", "Sigma", "Tau", "Uplsilon", "Phi", "Chi", "Psi", "Omega",
	"alpha", "beta", "gamma", "delta", "epsilon", "zeta", "eta", "theta",
	"iota", "kappa", "lambda", "mu", "nu", "xi", "omicron", "pi", "rho",
	"sigmaf","sigma", "tau", "upsilon", "phi", "chi", "psi", "omega",
	"thetasym", "upsih", "piv", "bull", "hellip", "prime", "Prime",
	"oline", "frasl", "weierp", "image", "real", "trade", "alefsym",
	"larr", "uarr", "rarr", "darr", "harr", "crarr", "lArr", "uArr",
	"rArr", "dArr", "hArr", "forall", "part", "exist", "empty", "nabla",
	"isin", "notin", "ni", "prod", "sum", "minus", "lowast", "radic", 
	"prop", "infin", "ang", "and", "or", "cap", "cup", "int", "there4",
	"sim", "cong", "asymp", "ne", "equiv", "le", "ge", "sub", "sup",
	"nsub", "sube", "supe", "oplus", "otimes", "perp", "sdot", "lceil",
	"rceil", "lfloor", "rfloor", "lang", "rang", "loz", "spades", "clubs",
	"hearts", "diams", NULL
};

static gchar* MARKUP_INTL[] = {
	"quot", "amp", "lt", "gt", "OElig", "oelig", "Scaron", "scaron",
	"Yuml", "circ", "tilde", "ensp", "emsp", "thinsp", "zwnj", "zwj", 
	"lrm", "rlm", "ndash", "mdash", "lsquo", "rsquo", "sbquo", "ldquo",
	"rdquo", "bdquo", "dagger", "Dagger", "permil", "lsaquo", "rsaquo",
	"euro",	NULL
};

/* ucs char values, don't need one for ISO-8859-1 as the values are just 
   160 + array index */

static glong MATH_GREEK_SYMBOLIC_ucs[] = {
	402, 913, 914, 915, 916, 917, 918, 919, 920, 921, 922, 923, 924,
	925, 926, 927, 928, 929, 931, 932, 933, 934, 935, 936, 937, 945,
	946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 957, 958,
	959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 977, 978, 982,
	8226, 8230, 8242, 8443, 8254, 8260, 8472, 8465, 8476, 8482, 8501,
	8592, 8593, 8594, 8595, 8596, 8629, 8656, 8657, 8658, 8659, 8660,
	8704, 8706, 8707, 8709, 8711, 8712, 8713, 8715, 8719, 8721, 8722, 
	8727, 8730, 8733, 8734, 8736, 8743, 8744, 8745, 8746, 8747, 8756,
	8764, 8773, 8776, 8800, 8801, 8804, 8805, 8834, 8835, 8836, 8838,
	8839, 8853, 8855, 8869, 8901, 8968, 8969, 8970, 8971, 9001, 9002,
	9674, 9824, 9827, 9829, 9830, -1
};

static glong MARKUP_INTL_ucs[] = {
	34, 38, 60, 62, 338, 339, 352, 353, 376, 710, 732, 8194, 8195, 8201,
	8204, 8205, 8206, 8207, 8211, 8212, 8216, 8217, 8218, 8220, 8221, 8222,
	8224, 8207, 8211, 8212, 8216, 8217, 8218, 8220, 8221, 8222, 8224, 8225, 8240,
	8249, 8250, 8364, -1
};
